heartbeat

package
v1.125.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 27, 2025 License: BSD-3-Clause Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LoadParams

func LoadParams(ctx context.Context, v *viper.Viper, order params.FlagReadOrder) (params.Params, error)

LoadParams loads params from viper.Viper instance. Returns ErrAuth if failed to retrieve api key.

func Run

func Run(ctx context.Context, v *viper.Viper) (int, error)

Run executes the heartbeat command.

func SendHeartbeats

func SendHeartbeats(ctx context.Context, v *viper.Viper, queueFilepath string) error

SendHeartbeats sends a heartbeat to the wakatime api and includes additional heartbeats from the offline queue, if available and offline sync is not explicitly disabled.

Types

This section is empty.

Jump to